import time
from math import sin
from ezprogbar import ProgressBar

def test1():
    pb = ProgressBar(240)
    for i in range(240):
        time.sleep(0.03)
        pb.advance()


def callback(pb):
    i = pb.index
    t = pb.seconds
    p = pb.percent

    if p in [20, 45, 82]:
        print("Hi from callback: index=%d, time=%.2f seconds, percent=%d%%" % (i,t,p))

    if t > 100:
        print("This is taking too long!")

def test2():
    n = 2*10**6
    pb = ProgressBar(n, callback=callback)
    s = 0.0
    for i in range(n):
        s += 1.0/(1 + i**(2+sin(i)))
        pb.advance()

    print("Result: s = %.6f" % (s,))

test1()
test2()





from __future__ import print_function
import sys, time

class ProgressBar:
    """
    Example:
    pb = ProgressBar(n)
    for i in range(n):
        do_some_action()
        pb.advance()
    """

    def __init__(self, size, **opt):
        prompt = opt.get('prompt', 'Progress: ')
        self.size = size
        self.unit = size / 100.0
        self.percent = -1
        self.index = 0
        self.done = False
        self.start = time.time()
        self.text = '\r' + prompt + '%d%%   '
        self.callback = opt.get('callback', None)

    def advance(self, n=None):
        if self.done:
            return
        if n is None:
            self.index += 1
        else:
            self.index = n

        p = int(self.index / self.unit)

        if p > self.percent:
            sys.stdout.write(self.text % p)
            sys.stdout.flush()
            self.percent = p
            self.seconds = time.time() - self.start
            if self.callback:
                self.callback(self)

        if self.index >= self.size - 1:
            sys.stdout.write((self.text + '\n') % 100)
            sys.stdout.flush()
            self.done = True
            t = time.time() - self.start
            print("Time: %.2f seconds" % t)





from setuptools import setup

setup(name='ezprogbar',
    version='1.21',
    description='simple textual progress bar',
    url='http://github.com/samyzaf/ezprogbar',
    author='Samy Zafrany',
    author_email='admin@samyzaf.com',
    license='MIT',
    packages=['ezprogbar'],
    zip_safe=False,
)

